# jQuery UI MultiSelect Widget

MultiSelect progessively enhances an ordinary multiple select control into elegant drop down list of checkboxes, stylable with ThemeRoller.  

![Example](http://www.erichynds.com/examples/jquery-multiselect/screenshot-widget.gif)
